@@ -16,80 +16,14 @@
 #ifndef CAML_CONFIG_H
 #define CAML_CONFIG_H
 
-#undef ARCH_SIXTYFOUR
-#define SIZEOF_INT 4
-#define SIZEOF_LONG 4
-#define SIZEOF_PTR 4
-#define SIZEOF_SHORT 2
-#define SIZEOF_LONGLONG 8
-#define INT64_LITERAL(s) s ## LL
-#undef ARCH_BIG_ENDIAN
-#define ARCH_ALIGN_DOUBLE
-#define ARCH_ALIGN_INT64
-#define ASM_CFI_SUPPORTED
-#define PROFINFO_WIDTH 0
-#define CAML_WITH_CPLUGINS
-#define OCAML_OS_TYPE "Unix"
-#define OCAML_STDLIB_DIR "/usr/lib/ocaml"
-#define POSIX_SIGNALS
-#define HAS_C99_FLOAT_OPS
-#define HAS_GETRUSAGE
-#define HAS_TIMES
-#define HAS_SECURE_GETENV
-#define HAS_TERMCAP
-#define HAS_SOCKETS
-#define HAS_SOCKLEN_T
-#define HAS_INET_ATON
-#define HAS_IPV6
-#define HAS_STDINT_H
-#define HAS_UNISTD
-#define HAS_OFF_T
-#define HAS_DIRENT
-#define HAS_REWINDDIR
-#define HAS_LOCKF
-#define HAS_MKFIFO
-#define HAS_GETCWD
-#define HAS_GETWD
-#define HAS_GETPRIORITY
-#define HAS_UTIME
-#define HAS_UTIMES
-#define HAS_DUP2
-#define HAS_FCHMOD
-#define HAS_TRUNCATE
-#define HAS_SYS_SELECT_H
-#define HAS_SELECT
-#define HAS_NANOSLEEP
-#define HAS_SYMLINK
-#define HAS_WAITPID
-#define HAS_WAIT4
-#define HAS_GETGROUPS
-#define HAS_SETGROUPS
-#define HAS_INITGROUPS
-#define HAS_TERMIOS
-#define HAS_ASYNC_IO
-#define HAS_SETITIMER
-#define HAS_GETHOSTNAME
-#define HAS_UNAME
-#define HAS_GETTIMEOFDAY
-#define HAS_MKTIME
-#define HAS_SETSID
-#define HAS_PUTENV
-#define HAS_LOCALE
-#define SUPPORT_DYNAMIC_LINKING
-#define HAS_MMAP
-#define HAS_PWRITE
-#define HAS_NANOSECOND_STAT 1
-#define HAS_GETHOSTBYNAME_R 6
-#define HAS_GETHOSTBYADDR_R 8
-#define HAS_MKSTEMP
-#define HAS_NICE
-#define HAS_DUP3
-#define HAS_PIPE2
-#define HAS_ACCEPT4
-#define HAS_SIGWAIT
-#define HAS_LIBBFD
-#define HAS_HUGE_PAGES
-#define HUGE_PAGE_SIZE (4 * 1024 * 1024)
+/* <include m.h> */
+/* <include s.h> */
+/* <private> */
+#include "m.h"
+#include "s.h"
+#ifdef BOOTSTRAPPING_FLEXLINK
+#undef SUPPORT_DYNAMIC_LINKING
+#endif
 
 #ifndef CAML_NAME_SPACE
 #include "compatibility.h"
@@ -99,6 +33,10 @@
 #include <stdint.h>
 #endif
 
+#ifndef ARCH_SIZET_PRINTF_FORMAT
+#define ARCH_SIZET_PRINTF_FORMAT "z"
+#endif
+
 /* Types for 32-bit integers, 64-bit integers, and
    native integers (as wide as a pointer type) */
 
@@ -121,14 +59,14 @@
 #endif
 
 #ifndef ARCH_INT64_TYPE
-#if SIZEOF_LONGLONG == 8
-#define ARCH_INT64_TYPE long long
-#define ARCH_UINT64_TYPE unsigned long long
-#define ARCH_INT64_PRINTF_FORMAT "ll"
-#elif SIZEOF_LONG == 8
+#if SIZEOF_LONG == 8
 #define ARCH_INT64_TYPE long
 #define ARCH_UINT64_TYPE unsigned long
 #define ARCH_INT64_PRINTF_FORMAT "l"
+#elif SIZEOF_LONGLONG == 8
+#define ARCH_INT64_TYPE long long
+#define ARCH_UINT64_TYPE unsigned long long
+#define ARCH_INT64_PRINTF_FORMAT "ll"
 #else
 #error "No 64-bit integer type available"
 #endif
